@@ -2,11 +2,6 @@ from PyObjCTools.TestSupport import *
 
 import StoreKit
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestSKError (TestCase):
 
     def test_constants(self):
@@ -18,6 +13,14 @@ class TestSKError (TestCase):
         self.assertEqual(StoreKit.SKErrorPaymentInvalid, 3)
         self.assertEqual(StoreKit.SKErrorPaymentNotAllowed, 4)
 
+        self.assertEqual(StoreKit.SKErrorPrivacyAcknowledgementRequired, 9)
+        self.assertEqual(StoreKit.SKErrorUnauthorizedRequestData, 10)
+
+        self.assertEqual(StoreKit.SKErrorInvalidOfferIdentifier, 11)
+        self.assertEqual(StoreKit.SKErrorInvalidSignature, 12)
+        self.assertEqual(StoreKit.SKErrorMissingOfferParams, 13)
+        self.assertEqual(StoreKit.SKErrorInvalidOfferPrice, 14)
+
 
 if __name__ == "__main__":
     main()
